bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 6. Aventiure
___________________________________________________ #### <Wie Gvnther gen Isenlaride nach Prvnhilt fvor>
| ### teniwiv mære sich huoben vber Rin ### man seite daz da were manich magedin ### der dahte im eine werben des kunich Gvnthers mvot ### daz dvhte sine rechen vn– die herren alle guot [14a] ### Ez was ein kvniginne gesezzen vber se ### ir geliche was deheiniv me ### si was vnmazen schone vil michel was ir kraft ### si schoz mit snellen degnen vmbe minne den schaft
###### 326 | ### Den stein warf si verre darnach si witen spranch ### swer ir minne gerte der muose ane wanch ### driv spil an gewinnen der vrowen wol geborn ### gebrast im an eime er het daz hovbet verlorn
###### 327 | ### Des hete div iunchfrowe vnmazen vil getan ### daz vernam bi dem Rine ein riter wol verstan ### der wande sine sinne an daz schoene wip ### darumbe helde vil mvosen sit verliesen den lip
###### 328 | ### Do sprach der voit von Rine ich wil an den se ### hin zuo Prvnhilde swie ez mir erge ### ich wil vmb ir minne wagen den lip ### den wil ich verliesen sin werde min wip
###### 329 | ### Daz wil ich widerraten sprach do Sifrit ### ia hat div kvniginne so vreislichen sit ### swer ir minne wirbet daz ez in hohe stat ### des mvget ir der reise haben guoten rat
###### 330 | ### So wil ich iv daz raten sprach do Hagene ### ir bitet Sifrit mit iv ce tragene ### die vil starken reise daz ist nu min rat ### sit ime daz ist kundech wie ez vmb die frovwen stat
###### 331 | ### Er sprach wil du mir helfen edel Syfrit ### die minnechlichen werben tuo des ich dich bit ### vnd wirt mir ze trûte daz minnechliche wip ### ich wil durch dinen willen wagen ere vnde lip
###### 332 | ### Des antwrte Sifrit Sigmundes sun ### gist dv mir din swester so wil ich ez tuon ### die schonen Chriemhilde ein kvniginne her ### so gere ich niht lones nach minen arbeiten mer
###### 333 | ### Daz lobe ich sprach Gvnther Sifrit an din hant ### vnd kumet die schoene Prvnhilt in daz lant ### so wil ich dir ze wibe mine swester geben ### so maht du mit ir immer vroliken leben
###### 334 | ### Des <swouren> si do eide die reken vil her ### des wart ir arbeite verre dester mer ### ê daz si die frovwen brahten an den Rin ### des muesen die kuonen sit in grozen noten sin
###### 335 | ### Sifrit muose fuoren die kappen mit im dan ### die der helt kuene mit sorge gewan ### ab eime getwerge daz hiez Albrich ### sich garten zvo der verte reken kuene vn– rich
###### 336 | ### Also der starke Sifrit die tarnkappe truoch ### so het er darinne krefte genuoch ### zwelf manne sterke zvo sin selbes lip ### er warp mit grozen listen daz herliche wip
###### 337 | ### ovch was div tranhût also getan [14b] ### daz darinne worhte ein islich man ### swaz er selbe wolde daz in nieman sach ### da mit gewanner Prvnhilde da von im leide gesach
###### 338 | ### Nv sage mir degen Sifrit ê min vart erge ### daz wir mit vollen eren komen an den se ### svln wir reke fuoren in Prunhilde lant ### drizech tusent degen die weren schier besant
###### 339 | ### Der gesellen bin ich einer der ander soldv wesen ### der drite daz si Hagne wir sulen wol genesen ### der vierde daz si Danchwart der vil kuene man ### tvsent man mit strite geturren nimmer vns bestan
###### 340 | ### Div mære wesse ich gerne sprach der kunich do ### ê wir hinnen fuern des wer ich harte fro ### waz wir chleider solden vor Prunhilde tragen ### div uns da wol zamnen Sifrit daz solt du mir sagen
###### 341 | ### Kleit daz aller beste daz ieman bevant ### treit man zallen citen in Prvnhilde lant ### des sulen wir richiu kleider vor der frovwen tragen ### daz wirs iht haben schande so man div mære hore sagen
###### 342 | ### Do enbot er siner swester daz er se wolde sehen ### vnd der degen Sifrit e daz was geschehen ### do hete sich div schoene ze lobe wol gekleit ### daz die herren chomen daz was in mezlichen leit
###### 343 | ### Nv was ovch ir ingesinde geciert als im gezam ### die fvrsten komen beide do si daz vernam ### do stuont si von dem sedele mit zvhten si do gie ### da si den gast vil edelen vnd ovch ir bruoder enphie
###### 344 | ### Si willekomen bruoder vnd der geselle sin ### div mere ich weste gerne sprach daz meidin ### waz ir herren woldet sit ir ze houe gat ### lat ir mich hoeren wie ez iv edelen reken stat
###### 345 | ### Do sprach der kvnich Gvnther frovwe ich wilz iv sagen ### wir muozen michel sorge bi hohme muote tragen ### wir wellen hubschen riten verre in fremdiv lant ### wir solden zuo der reisen haben cierlich gewant
###### 346 | ### Nv sicet lieber brvoder sprach daz kvniges kint ### lat mich rehte hoeren wer die frovwen sint ### der ir gert ze minne in ander kvnige lant ### die vz derwelten nam si beide bi der hant
###### 347 | ### Si gie mit in beiden da si ê da saz ### vf matraze riche ich wil wizzen daz ### geworht mit guoten b¡lden mit golde wol erhaben ### si mohten bi den frovwen gvot kurtzwile haben
###### 348 | ### Friuntliche bliche vnd guotlichen sehen ### des mohte von in beiden harte vil geschehent ### er truoch si in dem herzen si was im so der lip ### sit wart div schoene Chriemhilt des kvonen Sifrides wip
###### 349 | ### Do sprach div iunchfrovwe nu merket was ich sage ### ich han selbe siden nv schafet daz man trage [15a] ### gesteine vns vof den schilden so wurken wir div chleit ### des willen was do Gvnther vnd ovch Sifrit bereit
###### 350 | ### Wer sint die gesellen sprach div kvnigin ### die mit iv gecleidet ce hove sulen sin ### er sprach ich selbe vierde zwene mine man ### Danchwart vnd Hagne ze hove svlen mit mir gan
###### 351 | ### Frovwe merket rehte waz ich iv sage ### daz ich selbe vierde ze vier tagen trage ### ie drier hande chleider vnd also guot gewant ### daz wir ane schande rumen Prvnhilde lant
###### 352 | ### Mit guotem vrlovbe die herren schieden dan ### do hiez ir ivnchfrovwen drizech meide gan ### vz ir kemenaten div schoene <kvnigin> ### die zuo solhem werke hetet grozlichen sin
###### 353 | ### Die arabischen siden wiz also der sne ### vnd von Zazamanch der gruenen so der chle ### darin si leiten steine des wurden guotiv kleit ### selbe sneit si Chriemhilt div herliche meit
###### 354 | ### Von fremder <vische> hûten bezoch wol getan ### die ze sehenne waren den lvten fremde dan ### die dachten si mit siden so si si solden tragen ### nv hoeret wunder von der liehten wete sagen
###### 355 | ### Von Marroch dem lande vnd ovch von Cybian ### die aller besten siden die ie mer gewan ### deheines kvniges kvnne der heten si genuoch ### wol lie daz schinen Chriemhilt daz si in holden willen truoch
###### 356 | ### Sit si der hohen verte heten nv gegert ### hermine vedern duhten si vil wert ### darobe pfelle lagen swarz alsam ein kol ### daz noch snellen helden zeme in hochciten wol
###### 357 | ### Vz arabischem golde vil gesteines schein ### der frovwen vnmuoze was niht ze chlein ### inre siben wochen bereiten si div kleit ### do was ovch gewæfen den guoten reken bereit
###### 358 | ### Do si bireit waren do was in uf den Rin ### gemachet flizeklichen ein starkez schiflin ### daz si tragen solde nider an den se ### den edelen iunchfrovwen was von arebeiten we
###### 359 | ### Nach den hergesellen wart bote sa gesant ### ob si wolden schovwen niwez ir gewant ### ob ez den helden were ze kvrtz oder ze lanch ### ez was ze rehter maze des seiten si den frovwen danch
###### 360 | ### Vil michel danken wart da niht verdeit ### do gerten vrlobes die reken vngemeit ### in riterlichen zvhten die herren taten daz ### des wrden liehtiv ovgen von weinen truobe vn– naz
###### 361 | ### Si sprach vil lieber pruoder ir mohtet <noch> bestan ### vnd wurbet ander frovwen daz hiez ich wol getan ### vnde da iv niht enstvnde en wage so der lip [15b] ### ir muget hie nahen vinden ein als hoch geborn wip
###### 362 | ### Ich wene in sagte daz herze daz in da von geschach ### si weinten al geliche swaz ieman gesprach ### ir golt in vor den brusten wart von træhen sal ### die vielen in genote von den ovgen ze tal
###### 363 | ### Si sprach er Sifrit lat iv bevolhen sin ### vof triwe vnd vof genade den lieben bruoder min ### daz im iht werre in Prvnhilde lant ### daz lobte der vil kuene in Chriemhilde hant
###### 364 | ### Do sprach der degen riche ob mir min lip bestat ### so sult ier aller sorge frovwe haben rat ### ich bringe iv in gesvnden wider an den Rin ### daz wizet sicherlichen do neig im daz schone megdin
###### 365 | ### Ir golt varwen schilde man truoch in vof den sant ### vnde brahte in zuo zin allez ir gewant ### ros hiez man in ziehen si wolden riten dan ### da wart von schoenen frowen michel weinen getan
###### 366 | ### Do stuenden in div venster diu minneclichen kint ### ir schif mit dem segele ruorte ein hoher wint ### die stolcen hergesellen sazen an den Rin ### do sprach der kvnich Gunther wer <sol> schifmeister sin
###### 367 | ### Daz wil ich sprach Sifrit ich kan ivch <vof> der fluot ### hinnen wol gefuorn daz wizet helde guot ### die rehten wazzerstraze sint mir wol bechant ### si schieden froliche vz Burgonden lant
###### 368 | ### Sifrit do balde eine schalten gewan ### von stade er schieben vaste began ### Gvnther der kuene ein ruoder selbe nam ### do huoben sich von lande die snellen riter lobesam
###### 369 | ### Si fuorten riche spise dar zuo guoten win ### den besten den man kvnde vinden vmben Rin ### ir ros stuonden ebene si heten guot gemach ### irschif giench ovch ebene lucel leides in gesach
###### 370 | ### <Ir> starken segelseil wurden in gestraht ### si fuoren zweinzech mile end ez wurde naht ### mit eime guoten winde nider gein dem se ### ir starkez arbeiten tet sit schuonen frovwen we
###### 371 | ### An dem zwelften morgen so wir horen sagen ### heten si die winde verre dan getragen ### gen Isensteine in Prvnhilde lant ### daz was niemen mere wan Sifride bechant
###### 372 | ### Do der kvnich Gvnther so vil der bvrge sach ### vnd ovch die witen marke wie balde er do sprach ### saget mir frivnt her Sifrit ist iv daz bekant ### wes sint die bvrge vnd daz herliche lant
###### 373 | ### Des antwrte Sifrit ez ist mir wol bekant ### ez ist Prunhilde burge vnde lant ### vnd Isenstein div veste als ir mich hoere iehen ### da mvget ir hivte schoener frovwen vil gesehen [16a]
###### 374 | ### Ich wil iv helden raten ir habet einen mvot ### ir iehet geliche ia dunket ez mich guot ### swenne wir noch hivte fuer Prunhilde gan ### so muozen wir mit sorgen vor der kuniginne stant
###### 375 | ### So wir die minneclichen bi ir gesinde sehen ### so svlt ir helde mære wan einer rede iehen ### Gvnther si min herre vnd ich sin man ### des er da hat gedingen daz wirt allez getan
###### 376 | ### Des waren si bereite des er si loben hiez ### durch ir ubermvote deheiner ez niht liez ### si iahen swes er wolde da von in wol gesach ### do der kvnich Gvnther Prvnhile <sach>

<<< Übersicht <<< vorige Seite nächste Seite >>>